@@ -5,6 +5,7 @@ import sys
 from threading import Lock
 from typing import Callable, Iterable, Literal, Optional, TypeVar, Union, cast
 
+import requests
 import tqdm  # type: ignore
 
 OS = Literal["linux", "darwin"]
@@ -22,7 +23,7 @@ def get_distro() -> Optional[Distribution]:
     release_file = "/etc/os-release"
     with open(release_file) as release:
         for line in release:
-            k, v = line.split("=", 1)
+            k, v = line.strip().split("=", 1)
             if k == "ID":
                 return v
 
@@ -104,7 +105,7 @@ def flatten(items: Iterable[Iterable[T]]) -> list[T]:
     return [item for sublist in items for item in sublist]
 
 
-def parallel_map_tqdm(items: list[T], action: Callable[[T], U]) -> list[U]:
+def parallel_map_tqdm(action: Callable[[T], U], items: list[T]) -> list[U]:
     with tqdm.tqdm(total=len(items)) as progress:
         with concurrent.futures.ThreadPoolExecutor(20) as executor:
 
@@ -133,3 +134,8 @@ class Filters:
     @staticmethod
     def endswith(suffix: str) -> Callable[[str], bool]:
         return lambda x: x.endswith(suffix)
+
+
+def url_version(url: str) -> str:
+    head_response = requests.head(url, allow_redirects=True)
+    return head_response.headers["etag"]
